/*
  defines the format of an audio stream
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */


#include <deviceConfig/yafAudioInfo.h>



YafAudioInfo::YafAudioInfo(){
  makeInvalid();
  volume=100.0;
}


YafAudioInfo::~YafAudioInfo() {
}


void YafAudioInfo::setFormat(int stereo,int samplesize,int speed) {
  setStereo(stereo);
  setSampleSize(samplesize);
  setSpeed(speed);
}


int YafAudioInfo::getStereo() {
  return stereo;
}


int YafAudioInfo::getSampleSize() {
  return samplesize;
}


int YafAudioInfo::getSpeed() {
  return speed;
}

void YafAudioInfo::setStereo(int stereo) {
  this->stereo=stereo;
}


void YafAudioInfo::setSampleSize(int samplesize) {
  this->samplesize=samplesize;
}


void YafAudioInfo::setSpeed(int speed) {
  this->speed=speed;
}


float YafAudioInfo::getTime() {
  float time;

  time=8.0*(float)bytes/(float)(samplesize*(stereo+1));
  time=time/(float)(speed);

  return time;
}

void YafAudioInfo::setPlayedBytes(int bytes) {
  this->bytes=bytes;
}

int YafAudioInfo::getPlayedBytes() {
  return bytes;
}


void YafAudioInfo::setVolume(float percent) {
  volume=percent;
}


float YafAudioInfo::getVolume() {
  return volume;
}


int YafAudioInfo::equals(YafAudioInfo* aInfo) {
  if (aInfo == NULL) return false;

  if (aInfo->getSpeed() != speed) {
    return false;
  }
  if (aInfo->getStereo() != stereo) {
    return false;
  }
  if (aInfo->getSampleSize() != samplesize) {
    return false;
  }
  return true;
} 


void YafAudioInfo::copyTo(YafAudioInfo* aInfo) {
  if (aInfo == NULL) return;

  aInfo->setSpeed(getSpeed());
  aInfo->setStereo(getStereo());
  aInfo->setSampleSize(getSampleSize());
  aInfo->setPlayedBytes(getPlayedBytes());
  aInfo->setVolume(getVolume());
  
} 
 
int YafAudioInfo::isValid() {
  if (speed == -1) {
    return false;
  }
  if (stereo == -1) {
    return false;
  }

  if (samplesize == -1) {
    return false;
  }

  return true;
}


void YafAudioInfo::makeInvalid() {
  setStereo(-1);
  setSampleSize(-1);
  setSpeed(-1); 
}


void YafAudioInfo::print() {
  cout << "AudioInfo-begin-"<<endl;
  cout << "stereo:"<<getStereo()<<" sampleSize:"<<getSampleSize()
       << " speed: "<<getSpeed()<<" time:"<<getTime()
       << " vol: "<<getVolume()<< endl;
  cout << "AudioInfo-end-"<<endl;
 
}
